%define major 0
%define libname	%mklibname vosk %{major}
%define devname %mklibname vosk -d

%define pypi_name vosk

%global __provides_exclude_from %{python3_sitearch}/vosk/.*\\.so

Name:           vosk-api
Summary:        Offline speech recognition API
Version:        0.3.46
Release:        %mkrel 5
License:        ASL 2.0
Group:          Development/Python
URL:            https://github.com/alphacep/vosk-api
Source0:        https://github.com/alphacep/vosk-api/archive/refs/tags/go/v%{version}/vosk-api-%{version}.tar.gz
Patch1:         vosk-api-version.patch
Patch2:         vosk-api-lib-version.patch
Patch3:         vosk-api-python-arch.patch
Patch4:         vosk-api-python-import.patch
BuildRequires:  cmake
BuildRequires:  pkgconfig(python3)
BuildRequires:  kaldi-vosk-devel
BuildRequires:  openblas-devel
BuildRequires:  libatomic-devel
BuildRequires:  lapack-devel
BuildRequires:  openfst-devel
BuildRequires:  f2c

%description
Vosk is an offline open source speech recognition toolkit. It enables speech
recognition models for 18 languages and dialects. Vosk models provide
continuous large vocabulary transcription, zero-latency response with streaming
API, reconfigurable vocabulary and speaker identification.

%package -n %{libname}
Summary:	Offline speech recognition API
Group:		System/Libraries

%description -n %{libname}
Vosk is an offline open source speech recognition toolkit. It enables speech
recognition models for 18 languages and dialects. Vosk models provide
continuous large vocabulary transcription, zero-latency response with streaming
API, reconfigurable vocabulary and speaker identification.

%package -n %{devname}
Summary:        Development files for vosk
Group:          Development/C++
Requires:       %{libname} = %{version}-%{release}
Provides:       vosk-devel = %{version}-%{release}
Provides:       vosk-devel%{?_isa} = %{version}-%{release}
Conflicts:      python3-vosk-api < 0.3.46-2

%description -n %{devname}
Development libraries and headers for vosk.

%package -n python3-%{pypi_name}
Summary:        Vosk-api bindings for Python 3
%{?python_provide:%python_provide python3-%{pypi_name}}
Requires:       %{libname} = %{version}-%{release}
Obsoletes:      python3-vosk-api < 0.3.46-2

%description -n python3-%{pypi_name}
This is a Python module for Vosk.

Vosk is an offline open source speech recognition toolkit. It enables speech
recognition for 20+ languages and dialects - English, Indian English, German,
French, Spanish, Portuguese, Chinese, Russian, Turkish, Vietnamese, Italian,
Dutch, Catalan, Arabic, Greek, Farsi, Filipino, Ukrainian, Kazakh, Swedish,
Japanese, Esperanto, Hindi, Czech, Polish. More to come.

Vosk models are small (50 Mb) but provide continuous large vocabulary
transcription, zero-latency response with streaming API, reconfigurable
vocabulary and speaker identification.

Vosk supplies speech recognition for chatbots, smart home appliances, virtual
assistants. It can also create subtitles for movies, transcription for lectures
and interviews.

Vosk scales from small devices like Raspberry Pi or Android smartphone to big
clusters.

%prep
%autosetup -n vosk-api-go-v%{version} -p1

# Fix CMake project version
sed -i -e 's/@@VERSION@@/%{version}/' CMakeLists.txt

%generate_buildrequires
cd python
%pyproject_buildrequires

%build
%cmake
%cmake_build

pushd python
# generate vosk_cffi.py
python3 vosk_builder.py
%pyproject_wheel
popd

%install
%cmake_install

%pyproject_install
%pyproject_save_files %{pypi_name}

%files -n %{libname}
%doc README.md
%license COPYING
%{_libdir}/libvosk.so.%{major}{,.*}

%files -n %{devname}
%{_includedir}/vosk_api.h
%{_libdir}/libvosk.so

%files -n python3-%{pypi_name} -f %{pyproject_files}
%doc python/README.md
%license COPYING
%{_bindir}/vosk-transcriber


%changelog
* Tue Mar 04 2025 wally <wally> 0.3.46-5.mga10
+ Revision: 2160459
- rebuild for python3.13

* Sat Sep 07 2024 wally <wally> 0.3.46-4.mga10
+ Revision: 2093590
- add more provides to devel pkg

* Sat Sep 07 2024 wally <wally> 0.3.46-3.mga10
+ Revision: 2093586
- make python pkg to depend on lib pkg

* Sat Sep 07 2024 wally <wally> 0.3.46-2.mga10
+ Revision: 2093582
- rename src pkg as vosk-api
- add patches to build vosk lib with version and soversion
- add patch to build python module as arch dependant
- rename python pkg as python3-vosk

* Sun Feb 25 2024 papoteur <papoteur> 0.3.46-1.mga10
+ Revision: 2044132
- new version 0.3.46

* Fri Dec 29 2023 tv <tv> 0.3.45-3.mga10
+ Revision: 2023467
- Rebuild for python-3.12

* Sat Sep 30 2023 papoteur <papoteur> 0.3.45-2.mga10
+ Revision: 1992524
- add header file in a devel package for use with go compiler (see numen)

* Wed Sep 06 2023 papoteur <papoteur> 0.3.45-1.mga10
+ Revision: 1984840
- new 0.3.45

* Wed Sep 21 2022 wally <wally> 0.3.43-3.mga9
+ Revision: 1891143
- add patch to create properly named python wheels during the build
- enable debug pkg
- build using our compiler flags

* Tue Sep 20 2022 papoteur <papoteur> 0.3.43-2.mga9
+ Revision: 1890713
- workaround whl not installable on i586 and arm arches
- imported package python-vosk-api

